require 'rubygems'
require 'sinatra'
require 'sinatra/namespace'
require 'json'
require 'handlebars'
require 'bytesize'

before do
    content_type :json
end

namespace '/api/v2' do

    get '/config/verify/:hash' do
        {"valid":false}.to_json
    end

    get '/config/:name' do
        data = JSON.parse(File.read("payloads/config/#{params['name']}.json"))
        data['host'] = "#{request.scheme}://#{request.host}:#{request.port}"
        data.to_json
    end

    get '/users/:id' do
        File.read('payloads/users/id.json')
    end

    get '/*' do
        jsonfile = params['splat'][0]
        File.read("payloads/#{jsonfile}.json")
    end

    post '/*' do
        jsonfile = params['splat'][0]
        File.read("payloads/#{jsonfile}.json")
    end
end

get '/' do
    content_type :html

    items = {}
    lastv = {}
    Dir.children("public/apks").each do |x|
        versions = {}
        Dir.children("public/apks/#{x}").reverse_each do |y|
            if lastv.has_key?(x) == false
                lastv[x] = y
            end
            versions[y] = {}
            versions[y]['files'] = Dir.glob("public/apks/#{x}/#{y}/*.apk").map { |z| [z.delete_prefix('public/'), {
                name: z.split('/').last(),
                ctime: File.mtime(z).strftime('%d/%m/%Y'),
                size: File.bytesize(z).to_s
            }] }.to_h
            # vnotes[y] = ''
            Dir.glob("public/apks/#{x}/#{y}/notes.txt") do |z| 
                versions[y]['notes'] = File.read z
            end
        end
        items[x] = versions
    end
    # lastv.to_json
    # items.to_json
    # notes.to_json
    handlebars = Handlebars::Context.new
    handlebars.register_helper :is_last do |context, app, version, block|
        if lastv[app] == version
            block.fn(context)
        end
    end
    hbs = handlebars.compile(File.read('views/index.hbs'))
    hbs.call({items: items, lastv: lastv})
end

# public
get '/avatar/:id' do
    content_type :png
    send_file 'public/avatar.png'
end

get '/mailer_config/logo_app.png' do
    content_type :png
    send_file 'public/logo_app.png'
end
